@@ -42,6 +42,9 @@ _DEFAULT_CONFIG = {
         + "/covalent",
         "log_level": os.environ.get("LOGLEVEL", "WARNING").lower(),
         "enable_logging": os.environ.get("COVALENT_LOG_TO_FILE", "false").lower(),
+        "executor_dir": os.environ.get("COVALENT_EXECUTOR_DIR")
+        or (os.environ.get("XDG_CONFIG_DIR") or (os.environ["HOME"] + "/.config"))
+        + "/covalent/executor_plugins",
     },
     "dispatcher": {
         "address": "0.0.0.0",
